//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
USERES("InstallMgr.res");
USEFORM("MainFrm.cpp", MainForm);
USEFORM("StatusFrm.cpp", StatusForm);
USEFORM("RemoteMntFrm.cpp", RemoteMntForm);
USEFORM("InfoFrm.cpp", InfoForm);
USEFORM("cipherfrm.cpp", CipherForm);
USEFORM("UninstallFrm.cpp", UninstallForm);
USELIB("zlib.lib");
USELIB("..\..\..\..\lib\swordlib.lib");
USELIB("libcurl.lib");
USELIB("curl\lib\ws2_32.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icui18n.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icudatab.lib");
USELIB("..\..\..\..\..\icu-sword\as_is\borland\icucommon.lib");
//---------------------------------------------------------------------------
WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
{
	try
	{
		Application->Initialize();
		Application->Title = "Install Manager";
		Application->CreateForm(__classid(TMainForm), &MainForm);
		Application->CreateForm(__classid(TStatusForm), &StatusForm);
		Application->CreateForm(__classid(TRemoteMntForm), &RemoteMntForm);
		Application->CreateForm(__classid(TInfoForm), &InfoForm);
		Application->CreateForm(__classid(TCipherForm), &CipherForm);
		Application->CreateForm(__classid(TUninstallForm), &UninstallForm);
		Application->Run();
	}
	catch (Exception &exception)
	{
		Application->ShowException(&exception);
	}
	return 0;
}
//---------------------------------------------------------------------------
